@@ -94,6 +94,9 @@ gboolean terminal_window_get_fullscreen (TerminalWindow *window);
 
 void terminal_window_reread_profile_list (TerminalWindow *window);
 
+void terminal_window_set_startup_id (TerminalWindow *window,
+                                     const char     *startup_id);
+
 G_END_DECLS
 
 #endif /* TERMINAL_WINDOW_H */
